@@ -19,10 +19,8 @@ OC.L10N.register(
     "Cancel" : "キャンセル",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
-    "Deleted all completed tasks from calendar \"%s\"." : "カレンダー「%s」の完了した全てのタスクを削除",
     "No errors" : "エラーはありません",
     "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
-    "_This will delete {taskCount} completed task and its subtasks from calendar \"%s\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"%s\"._" : ["これにより、カレンダー「%s」から{taskCount}個の完了したタスクとそのサブタスクが削除されます。"],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
     "Load all completed tasks." : "完了済みタスクを読み込み",
     "Change sort order" : "並び順を変更",
@@ -44,19 +42,14 @@ OC.L10N.register(
     "Sort by manual order." : "手動で並べ替えます。",
     "Alphabetically" : "アルファベット順",
     "Sort by summary and priority." : "要約と優先順位で並べ替えます。",
-    "{complete} % completed" : "{complete} %完了",
     "Task is completed" : "タスク完了",
-    "Toggle visibility of all subtasks." : "すべてのサブタスクの表示/非表示を切り替えます。",
+    "{complete} % completed" : "{complete} %完了",
     "Toggle visibility of completed subtasks." : "完了したサブタスクの表示/非表示を切り替えます。",
+    "Toggle visibility of all subtasks." : "すべてのサブタスクの表示/非表示を切り替えます。",
     "[Yesterday]" : "[昨日]",
     "[Today]" : "[今日]",
     "[Tomorrow]" : "[明日]",
-    "Add a subtask to \"%s\"…" : "\"%s\"にサブタスクを追加…",
-    "Add a task to \"%s\"…" : "\"%s\"にタスクを追加…",
     "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
-    "Add an important task to \"%s\"…" : "\"%s\"に重要なタスクを追加…",
-    "Add a task due today to \"%s\"…" : "\"%s\"に今日期限が設定されているタスクを追加…",
-    "Add a current task to \"%s\"…" : "現在のタスクを \"%s\"に追加…",
     "Tomorrow" : "明日",
     "Set start date" : "開始日を設定",
     "Set start time" : "開始時刻を設定",
@@ -75,29 +68,20 @@ OC.L10N.register(
     "[Due tomorrow]" : "[明日まで]",
     "[Was due yesterday]" : "[昨日が期限]",
     "No priority assigned" : "優先順位が割り当てられていません",
-    "Priority %s: high" : "優先度 %s:高",
-    "Priority %s: medium" : "優先度 %s:中",
-    "Priority %s: low" : "優先度 %s:低",
-    "%s %% completed" : "%s %% 完了",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
-    "Last modified %s" : "%s最終更新",
-    "Created %s" : "%s作成",
-    "Completed %s" : "%s完了",
     "Edit" : "編集",
     "Copy private link" : "プライベートリンクをコピー",
     "Copied" : "コピーしました",
-    "Can not copy" : "コピーに失敗しました",
+    "Can not copy" : "コピーできません",
     "Download" : "ダウンロード",
     "Save" : "保存",
     "Add List…" : "リストを追加…",
     "New List" : "新規リスト",
     "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
     "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
-    "The name \"%s\" is already used." : "名前 \"%s\" はすでに使われています。",
     "An empty name is not allowed." : "件名を入力してください。",
-    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "カレンダー\"%s\"とカレンダーに対応するすべての予定と作業が削除されます。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
     "Settings" : "設定",
     "Default list" : "デフォルトリスト",
