@@ -22,12 +22,10 @@ OC.L10N.register(
     "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
     "Set due date" : "ระบุวันครบกำหนด",
     "Task not found!" : "ไม่พบงาน!",
-    "%s %% completed" : "%s %% เสร็จสมบูรณ์",
     "Edit" : "แก้ไข",
     "Download" : "ดาวน์โหลด",
     "Save" : "บันทึก",
     "New List" : "รายชื่อใหม่",
-    "The name \"%s\" is already used." : "ชื่อ \"%s\" ถูกใช้ไปแล้ว",
     "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
     "Settings" : "ตั้งค่า",
     "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
