@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "Встановіть термін",
     "All day" : "Всі дні",
     "Task not found!" : "Завдання не знайдене!",
-    "%s %% completed" : "%s %% завершено",
     "Edit" : "Редагувати",
     "Download" : "Завантажити",
     "Save" : "Зберегти",
     "New List" : "Новий список",
-    "The name \"%s\" is already used." : "Назва \"%s\" вже використовується.",
     "An empty name is not allowed." : "Порожнє поле не допускається.",
     "Settings" : "Налаштування",
     "Visibility of Smart Collections" : "Видимість Smart-колекції",
